@@ -1,15 +1,21 @@
-;# $Id: dump.pl,v 0.6 1998/06/04 16:08:27 ram Exp $
+;# $Id: dump.pl,v 0.7 2000/08/03 22:04:45 ram Exp $
 ;#
-;#  Copyright (c) 1995-1998, Raphael Manfredi
+;#  Copyright (c) 1995-2000, Raphael Manfredi
 ;#  
 ;#  You may redistribute only under the terms of the Artistic License,
 ;#  as specified in the README file that comes with the distribution.
 ;#
 ;# $Log: dump.pl,v $
-;# Revision 0.6  1998/06/04 16:08:27  ram
-;# Baseline for first beta release.
+;# Revision 0.7  2000/08/03 22:04:45  ram
+;# Baseline for second beta release.
 ;#
 
+sub ok {
+	my ($num, $ok) = @_;
+	print "not " unless $ok;
+	print "ok $num\n";
+}
+
 package dump;
 use Carp;
 
